/* WPC Smart Quick View for WooCommerce styles
----------------------------------------------------------------- */
.mfp-woosq .mfp-ajax-holder div.mfp-content {
  width: inherit;
  min-width: auto;
  max-width: none;
  min-height: auto;
  max-height: inherit;
}

.woocommerce.woosq-product div.product div.thumbnails > div {
  max-height: 100%;
}

.mfp-woosq .mfp-close {
  margin: 5px !important;
  overflow: hidden;
  right: 0 !important;
}
.mfp-woosq .mfp-close:before {
  color: inherit;
}
.mfp-woosq .mfp-preloader {
  width: 50px;
  height: 50px;
  margin-top: -25px;
  margin-left: -25px;
}
.mfp-woosq .mfp-preloader:before {
  width: 50px;
  height: 50px;
  line-height: 50px;
  font-size: 36px;
  color: var(--theme-color-text);
}
.mfp-woosq.mfp-bg {
  background-color: rgba(0, 0, 0, 0.2);
}
.mfp-woosq.mfp-wrap .woosq-popup {
  -webkit-box-shadow: 0 3px 56px rgba(0, 0, 0, 0.1);
  -ms-box-shadow: 0 3px 56px rgba(0, 0, 0, 0.1);
  box-shadow: 0 3px 56px rgba(0, 0, 0, 0.1);
}
.mfp-woosq .mfp-arrow:before {
  font-family: "fontello";
  font-size: 36px;
  font-weight: 400;
  color: var(--theme-color-text);
  position: relative;
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
}
.mfp-woosq .mfp-arrow.mfp-arrow-left:before {
  content: '\e92a';
  left: 0;
}
.mfp-woosq .mfp-arrow.mfp-arrow-left:hover:before {
  left: -5px;
  right: auto;
}
.mfp-woosq .mfp-arrow.mfp-arrow-right:before {
  content: '\e92b';
  right: 0;
  left: auto;
}
.mfp-woosq .mfp-arrow.mfp-arrow-right:hover:before {
  right: -5px;
}

.woosq-product > .product .thumbnails {
  background-color: var(--theme-color-alter_bg_color);
}
.woosq-product > .product .summary {
  padding: 0 !important;
  background-color: var(--theme-color-alter_bg_color);
}
.woosq-product > .product .summary .summary-content {
  padding: 55px 40px;
}
.woosq-product .thumbnails .slick-arrow {
  width: 50px;
  height: 50px;
  line-height: 50px;
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
  color: var(--theme-color-text_dark);
  background-color: transparent;
  cursor: pointer;
  padding: 0 6px;
}
.woosq-product .thumbnails .slick-arrow:hover {
  background-color: transparent;
  color: var(--theme-color-text_dark);
}
.woosq-product .thumbnails .slick-arrow:before {
  font-size: 30px;
  line-height: 50px;
  font-weight: 400;
  font-family: "fontello";
}
.woosq-product .thumbnails .slick-arrow.slick-next {
  right: 15px;
}
.woosq-product .thumbnails .slick-arrow.slick-next:hover {
  padding-right: 0;
}
.woosq-product .thumbnails .slick-arrow.slick-next:before {
  content: '\e92b';
}
.woosq-product .thumbnails .slick-arrow.slick-prev {
  left: 15px;
}
.woosq-product .thumbnails .slick-arrow.slick-prev:hover {
  padding-left: 0;
}
.woosq-product .thumbnails .slick-arrow.slick-prev:before {
  content: '\e92a';
}
.woosq-product .thumbnails .slick-dots {
  bottom: 28px;
}
.woosq-product .thumbnails .slick-dots li {
  width: 24px;
  height: 24px;
}
.woosq-product .thumbnails .slick-dots li button {
  width: 24px;
  height: 24px;
  padding: 0;
  opacity: 1;
}
.woosq-product .thumbnails .slick-dots li button:before {
  width: 10px;
  height: 10px;
  margin: auto;
  -webkit-transition: all 0.3s ease;
  -ms-transition: all 0.3s ease;
  transition: all 0.3s ease;
  background-color: #C8C8C8;
  opacity: 0.8;
}
.woosq-product .thumbnails .slick-dots li button:hover:before {
  opacity: 1;
}
.woosq-product .thumbnails .slick-dots li.slick-active button:before {
  background-color: var(--theme-color-text_link);
  opacity: 1;
}

.woosq-sidebar {
  background-color: var(--theme-color-bg_color);
  font-size: 1rem;
}
.woosq-sidebar .woosq-product > .product .thumbnails {
  background-color: var(--theme-color-alter_bg_color);
}
.woosq-sidebar .woosq-product > .product .summary {
  background-color: var(--theme-color-bg_color);
}

.woosq-sidebar .woocommerce div.product .product_title,
.woosq-popup .woocommerce div.product .product_title {
  font-size: 24px;
  letter-spacing: 0;
  margin: 0 0 9px;
}
.woosq-sidebar .woocommerce div.product p.price,
.woosq-sidebar .woocommerce div.product span.price,
.woosq-popup .woocommerce div.product p.price,
.woosq-popup .woocommerce div.product span.price {
  font-size: 20px;
}
.woosq-sidebar .woocommerce div.product span.price,
.woosq-popup .woocommerce div.product span.price {
  padding-bottom: 15px;
}
.woosq-sidebar .woocommerce div.product p.price,
.woosq-popup .woocommerce div.product p.price {
  margin: 0 0 20px;
}
.woosq-sidebar .woocommerce div.product form.cart .variations,
.woosq-popup .woocommerce div.product form.cart .variations {
  margin-bottom: 20px;
}
.woosq-sidebar .woocommerce div.product form.cart .variations .trx_addons_attrib_extended,
.woosq-popup .woocommerce div.product form.cart .variations .trx_addons_attrib_extended {
  will-change: transform;
}
.woosq-sidebar .woocommerce div.product form.cart,
.woosq-popup .woocommerce div.product form.cart {
  margin-bottom: 23px;
}
.woosq-sidebar .woocommerce div.product form.cart .single_add_to_cart_button,
.woosq-popup .woocommerce div.product form.cart .single_add_to_cart_button {
  margin-right: 5px;
}
.woosq-sidebar .woocommerce div.product form.cart div.quantity,
.woosq-popup .woocommerce div.product form.cart div.quantity {
  width: 110px;
  height: 48px;
  margin: 0 5px 0 0;
}
.woosq-sidebar .woocommerce div.product form.cart div.quantity input[type="number"],
.woosq-popup .woocommerce div.product form.cart div.quantity input[type="number"] {
  padding-right: 40px;
}
.woosq-sidebar .woocommerce div.product form.cart div.quantity span,
.woosq-popup .woocommerce div.product form.cart div.quantity span {
  padding-left: 8px;
  width: 39px;
  line-height: 1.55em;
}
.woosq-sidebar .woocommerce div.product form.cart div.quantity span.q_dec,
.woosq-popup .woocommerce div.product form.cart div.quantity span.q_dec {
  line-height: 1em;
}
.woosq-sidebar .woocommerce div.product form.cart .single_add_to_cart_button,
.woosq-popup .woocommerce div.product form.cart .single_add_to_cart_button {
  height: 48px;
  line-height: 48px !important;
  padding: 0 40px 1px !important;
}
.woosq-sidebar .woocommerce div.product form.cart .tinv-wraper > .tinvwl_add_to_wishlist_button,
.woosq-popup .woocommerce div.product form.cart .tinv-wraper > .tinvwl_add_to_wishlist_button {
  width: 48px;
  height: 48px;
  line-height: 49px !important;
  margin-right: 5px;
}
.woosq-sidebar .woocommerce div.product .woocommerce-product-details__short-description,
.woosq-popup .woocommerce div.product .woocommerce-product-details__short-description {
  margin-bottom: 20px;
  font-size: 16px;
  line-height: 1.6em;
}
.woosq-sidebar .woocommerce div.product form.cart .variations tr + tr .label,
.woosq-popup .woocommerce div.product form.cart .variations tr + tr .label {
  padding-top: 8px;
}
.woosq-sidebar .woocommerce div.product .summary .stock,
.woosq-popup .woocommerce div.product .summary .stock {
  margin-bottom: 20px;
}
.woosq-sidebar .woocommerce div.product .product_meta span,
.woosq-popup .woocommerce div.product .product_meta span {
  font-size: 16px;
}
.woosq-sidebar .woocommerce div.product .product_meta span + span,
.woosq-popup .woocommerce div.product .product_meta span + span {
  margin-top: 8px;
}

.woosq-btn {
  display: inline-block;
  margin: 10px 0 0 0;
  font-size: 15px;
  line-height: 21px;
  font-weight: 700;
}

div > .woosq-btn:first-child {
  margin: 0 0 10px 0;
}

button.woosq-btn {
  cursor: pointer;
  padding: 10px 20px;
  -webkit-border-radius: 0;
  -ms-border-radius: 0;
  border-radius: 0;
  color: var(--theme-color-inverse_link);
  background-color: var(--theme-color-text_link);
}
button.woosq-btn:hover {
  color: var(--theme-color-inverse_link);
  background-color: var(--theme-color-text_hover);
}

@media (max-width: 1023px) {
  .woosq-product > .product .summary .summary-content {
    padding: 30px;
  }

  .woosq-product > .product .thumbnails,
  .woosq-product .thumbnails .slick-track,
  .woosq-product .thumbnails img {
    max-height: 480px;
  }
}
@media (max-width: 767px) {
  .woosq-product > .product .summary .summary-content {
    padding: 20px;
  }
}
@media (max-width: 479px) {
  .woosq-sidebar .woocommerce div.product form.cart div.quantity,
  .woosq-popup .woocommerce div.product form.cart div.quantity {
    margin-bottom: 10px;
    float: none;
  }
}

/*# sourceMappingURL=woo-smart-quick-view.css.map */
